@@ -4,6 +4,7 @@ import atexit
 import curses
 import os
 import pathlib
+import shutil
 import threading
 import time
 from collections import defaultdict
@@ -259,7 +260,7 @@ class CursesMenu:
                 curses.cbreak()
                 CursesMenu.stdscr.keypad(True)  # noqa: FBT003
                 # noinspection PyBroadException
-                try:
+                try:  # noqa: SIM105
                     curses.start_color()
                 except:  # noqa: E722 # pragma: no cover all
                     pass
@@ -273,7 +274,10 @@ class CursesMenu:
                 curses.endwin()
                 curses.echo()
                 curses.nocbreak()
-                os.system("stty echo")
+                if (
+                    shutil.which("[") is not None and shutil.which("stty") is not None
+                ):  # pragma: no cover all
+                    os.system("[ -t 0 ] && stty echo")
         else:
             self._main_loop()
 
@@ -346,7 +350,8 @@ class CursesMenu:
                 index_text = index_text.zfill(pad_width)
 
         text_style = self.highlight if self.current_option == index else self.normal
-        assert self.screen is not None and text_style is not None
+        assert self.screen is not None
+        assert text_style is not None
 
         self.screen.addstr(
             MIN_SIZE - 1 + index,
