@@ -4,15 +4,15 @@ from cursesmenu import CursesMenu
 from cursesmenu.items import MenuItem
 
 
-@pytest.fixture
+@pytest.fixture()
 def basic_item():
-    yield MenuItem("item")
+    return MenuItem("item")
 
 
-@pytest.fixture
+@pytest.fixture()
 def item_with_menu():
     menu = CursesMenu()
-    yield MenuItem("item with menu", menu=menu)
+    return MenuItem("item with menu", menu=menu)
 
 
 def test_str(basic_item: MenuItem):
